==> sword-1.5.5.tar.gz: sword-1.5.5/apps/windoze/CBuilder5/BibleCS/swordlib.cpp <==
//---------------------------------------------------------------------------
#include <condefs.h>
#pragma hdrstop
USEUNIT("..\..\..\..\src\keys\versekey.cpp");
USEUNIT("..\..\..\..\src\keys\swkey.cpp");
USEUNIT("..\..\..\..\src\keys\listkey.cpp");
USEUNIT("..\..\..\..\src\keys\strkey.cpp");
USEUNIT("..\..\..\..\src\mgr\swmgr.cpp");
USEUNIT("..\..\..\..\src\mgr\swconfig.cpp");
USEUNIT("..\..\..\..\src\modules\comments\rawcom\rawcom.cpp");
USEUNIT("..\..\..\..\src\modules\comments\swcom.cpp");
USEUNIT("..\..\..\..\src\modules\common\rawverse.cpp");
USEUNIT("..\..\..\..\src\modules\common\rawstr.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfrtf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfplain.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\rawld\rawld.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\swld.cpp");
USEUNIT("..\..\..\..\src\modules\texts\rawtext\rawtext.cpp");
USEUNIT("..\..\..\..\src\modules\texts\swtext.cpp");
USEUNIT("..\..\..\..\src\modules\swmodule.cpp");
USEUNIT("..\..\tbdisp.cpp");
USEUNIT("..\..\swwinlog.cpp");
USEUNIT("..\..\..\..\src\modules\comments\hrefcom\hrefcom.cpp");
USEUNIT("..\..\..\..\src\mgr\filemgr.cpp");
USEUNIT("..\..\..\..\src\modules\comments\rawfiles\rawfiles.cpp");
USEUNIT("..\..\..\..\src\utilfuns\utilstr.cpp");
USEUNIT("..\..\..\..\src\utilfuns\utilconf.cpp");
USEUNIT("..\..\..\..\src\utilfuns\Greek2Greek.cpp");
USEUNIT("..\..\..\..\src\utilfuns\regex.c");
USEUNIT("..\..\..\..\src\frontend\swlog.cpp");
USEUNIT("..\..\..\..\src\frontend\swdisp.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfstrongs.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbffootnotes.cpp");
USEUNIT("..\..\..\..\src\modules\filters\cipherfil.cpp");
USEUNIT("..\..\..\..\src\modules\common\sapphire.cpp");
USEUNIT("..\..\..\..\src\modules\common\swcipher.cpp");
USEUNIT("..\..\..\..\src\mgr\swlocale.cpp");
USEUNIT("..\..\..\..\src\mgr\localemgr.cpp");
USEUNIT("..\..\..\..\src\modules\common\lzsscomprs.cpp");
USEUNIT("..\..\..\..\src\modules\common\zverse.cpp");
USEUNIT("..\..\..\..\src\modules\common\swcomprs.cpp");
USEUNIT("..\..\..\..\src\modules\texts\ztext\ztext.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlrtf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfthml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\plainfootnotes.cpp");
USEUNIT("..\..\..\..\src\modules\filters\plainhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\rtfhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlgbf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlplain.cpp");
USEUNIT("..\..\..\..\src\modules\comments\zcom\zcom.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfheadings.cpp");
USEUNIT("..\..\..\..\src\modules\common\rawstr4.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\rawld4\rawld4.cpp");
USEUNIT("..\..\..\..\src\modules\common\zipcomprs.cpp");
USEUNIT("..\..\..\..\src\utilfuns\zlib\uncompr.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\compress.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\inflate.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\deflate.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\zutil.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\trees.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\maketree.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\infutil.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\inftrees.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\inffast.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\infcodes.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\infblock.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\crc32.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\adler32.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\gzio.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\untgz.c");
USEUNIT("..\..\..\..\src\modules\filters\unicodertf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfmorph.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlolb.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfhtmlhref.cpp");
USEUNIT("..\..\..\..\src\modules\filters\latin1utf8.cpp");
USEUNIT("..\..\..\..\src\modules\filters\latin1utf16.cpp");
USEUNIT("..\..\..\..\src\modules\filters\scsuutf8.cpp");
USEUNIT("..\..\..\..\src\modules\filters\swbasicfilter.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlhtmlhref.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8cantillation.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8greekaccents.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8hebrewpoints.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8transliterator.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8utf16.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf16utf8.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8latin1.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8html.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlscripref.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlheadings.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmllemma.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlmorph.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlfootnotes.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlstrongs.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8nfkd.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8nfc.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8bidireorder.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8arshaping.cpp");
USEUNIT("..\..\..\..\src\mgr\markupfiltmgr.cpp");
USEUNIT("..\..\..\..\src\mgr\encfiltmgr.cpp");
USEUNIT("..\..\..\..\src\mgr\swfiltermgr.cpp");
USEUNIT("..\..\..\..\src\utilfuns\swversion.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\zld\zld.cpp");
USEUNIT("..\..\..\..\src\modules\common\zstr.cpp");
USEUNIT("..\..\..\..\src\modules\common\entriesblk.cpp");
USEUNIT("..\..\..\..\src\modules\genbook\swgenbook.cpp");
USEUNIT("..\..\..\..\src\modules\genbook\rawgenbook\rawgenbook.cpp");
USEUNIT("..\..\..\..\src\keys\treekey.cpp");
USEUNIT("..\..\..\..\src\keys\treekeyidx.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlvariants.cpp");
USEUNIT("..\..\..\..\src\mgr\swcacher.cpp");
USEUNIT("..\..\..\..\src\modules\filters\greeklexattribs.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfosis.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlosis.cpp");
USEUNIT("..\..\..\..\src\mgr\installmgr.cpp");
USEUNIT("..\..\..\..\src\utilfuns\ftpparse.c");
USEUNIT("..\..\..\..\src\utilfuns\roman.cpp");
//---------------------------------------------------------------------------
#define Library

// To add a file to the library use the Project menu 'Add to Project'.

==> sword-1.5.6.tar.gz: sword-1.5.6/apps/windoze/CBuilder5/BibleCS/swordlib.cpp <==
//---------------------------------------------------------------------------
#include <condefs.h>
#pragma hdrstop
USEUNIT("..\..\..\..\src\keys\versekey.cpp");
USEUNIT("..\..\..\..\src\keys\swkey.cpp");
USEUNIT("..\..\..\..\src\keys\listkey.cpp");
USEUNIT("..\..\..\..\src\keys\strkey.cpp");
USEUNIT("..\..\..\..\src\mgr\swmgr.cpp");
USEUNIT("..\..\..\..\src\mgr\swconfig.cpp");
USEUNIT("..\..\..\..\src\modules\comments\rawcom\rawcom.cpp");
USEUNIT("..\..\..\..\src\modules\comments\swcom.cpp");
USEUNIT("..\..\..\..\src\modules\common\rawverse.cpp");
USEUNIT("..\..\..\..\src\modules\common\rawstr.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfrtf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfplain.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\rawld\rawld.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\swld.cpp");
USEUNIT("..\..\..\..\src\modules\texts\rawtext\rawtext.cpp");
USEUNIT("..\..\..\..\src\modules\texts\swtext.cpp");
USEUNIT("..\..\..\..\src\modules\swmodule.cpp");
USEUNIT("..\..\tbdisp.cpp");
USEUNIT("..\..\swwinlog.cpp");
USEUNIT("..\..\..\..\src\modules\comments\hrefcom\hrefcom.cpp");
USEUNIT("..\..\..\..\src\mgr\filemgr.cpp");
USEUNIT("..\..\..\..\src\modules\comments\rawfiles\rawfiles.cpp");
USEUNIT("..\..\..\..\src\utilfuns\utilstr.cpp");
USEUNIT("..\..\..\..\src\utilfuns\utilconf.cpp");
USEUNIT("..\..\..\..\src\utilfuns\Greek2Greek.cpp");
USEUNIT("..\..\..\..\src\utilfuns\regex.c");
USEUNIT("..\..\..\..\src\frontend\swlog.cpp");
USEUNIT("..\..\..\..\src\frontend\swdisp.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfstrongs.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbffootnotes.cpp");
USEUNIT("..\..\..\..\src\modules\filters\cipherfil.cpp");
USEUNIT("..\..\..\..\src\modules\common\sapphire.cpp");
USEUNIT("..\..\..\..\src\modules\common\swcipher.cpp");
USEUNIT("..\..\..\..\src\mgr\swlocale.cpp");
USEUNIT("..\..\..\..\src\mgr\localemgr.cpp");
USEUNIT("..\..\..\..\src\modules\common\lzsscomprs.cpp");
USEUNIT("..\..\..\..\src\modules\common\zverse.cpp");
USEUNIT("..\..\..\..\src\modules\common\swcomprs.cpp");
USEUNIT("..\..\..\..\src\modules\texts\ztext\ztext.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlrtf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfthml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\plainfootnotes.cpp");
USEUNIT("..\..\..\..\src\modules\filters\plainhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\rtfhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlgbf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlhtml.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlplain.cpp");
USEUNIT("..\..\..\..\src\modules\comments\zcom\zcom.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfheadings.cpp");
USEUNIT("..\..\..\..\src\modules\common\rawstr4.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\rawld4\rawld4.cpp");
USEUNIT("..\..\..\..\src\modules\common\zipcomprs.cpp");
USEUNIT("..\..\..\..\src\utilfuns\zlib\uncompr.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\compress.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\inflate.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\deflate.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\zutil.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\trees.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\maketree.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\infutil.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\inftrees.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\inffast.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\infcodes.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\infblock.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\crc32.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\adler32.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\gzio.c");
USEUNIT("..\..\..\..\src\utilfuns\zlib\untgz.c");
USEUNIT("..\..\..\..\src\modules\filters\unicodertf.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfmorph.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfhtmlhref.cpp");
USEUNIT("..\..\..\..\src\modules\filters\latin1utf8.cpp");
USEUNIT("..\..\..\..\src\modules\filters\latin1utf16.cpp");
USEUNIT("..\..\..\..\src\modules\filters\scsuutf8.cpp");
USEUNIT("..\..\..\..\src\modules\filters\swbasicfilter.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlhtmlhref.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8cantillation.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8greekaccents.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8hebrewpoints.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8transliterator.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8utf16.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf16utf8.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8latin1.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8html.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlscripref.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlheadings.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmllemma.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlmorph.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlfootnotes.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlstrongs.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8nfkd.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8nfc.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8bidireorder.cpp");
USEUNIT("..\..\..\..\src\modules\filters\utf8arshaping.cpp");
USEUNIT("..\..\..\..\src\mgr\markupfiltmgr.cpp");
USEUNIT("..\..\..\..\src\mgr\encfiltmgr.cpp");
USEUNIT("..\..\..\..\src\mgr\swfiltermgr.cpp");
USEUNIT("..\..\..\..\src\utilfuns\swversion.cpp");
USEUNIT("..\..\..\..\src\modules\lexdict\zld\zld.cpp");
USEUNIT("..\..\..\..\src\modules\common\zstr.cpp");
USEUNIT("..\..\..\..\src\modules\common\entriesblk.cpp");
USEUNIT("..\..\..\..\src\modules\genbook\swgenbook.cpp");
USEUNIT("..\..\..\..\src\modules\genbook\rawgenbook\rawgenbook.cpp");
USEUNIT("..\..\..\..\src\keys\treekey.cpp");
USEUNIT("..\..\..\..\src\keys\treekeyidx.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlvariants.cpp");
USEUNIT("..\..\..\..\src\mgr\swcacher.cpp");
USEUNIT("..\..\..\..\src\modules\filters\greeklexattribs.cpp");
USEUNIT("..\..\..\..\src\modules\filters\gbfosis.cpp");
USEUNIT("..\..\..\..\src\modules\filters\thmlosis.cpp");
USEUNIT("..\..\..\..\src\mgr\installmgr.cpp");
USEUNIT("..\..\..\..\src\utilfuns\ftpparse.c");
USEUNIT("..\..\..\..\src\utilfuns\roman.cpp");
USEUNIT("..\..\..\..\SRC\MODULES\FILTERS\osisstrongs.cpp");
USEUNIT("..\..\..\..\SRC\MODULES\FILTERS\osismorph.cpp");
//---------------------------------------------------------------------------
#define Library

// To add a file to the library use the Project menu 'Add to Project'.
